/*******************************************************************************************/
/**                                                                                       **/
/** COPYRIGHT (C) 2018, Systemyde International Corporation, ALL RIGHTS RESERVED          **/
/**                                                                                       **/
/** time module fpga top level                                        Rev 0.0  08/20/2018 **/
/**                                                                                       **/
/*******************************************************************************************/
module time_top (data_drv, data_out, fi_drv, fi_out, isa_drv, isa_out, spi_so, data_bus,
                 isa_bus, osc_in, ph1, ph2, pwr_up, pwo, spi_csn, spi_sck, spi_si, sync);

  input         data_bus;      /* memory/peripheral data bus                          bus  */
  input         isa_bus;       /* instruction address/data bus                        bus  */
  input         osc_in;        /* 32768Hz clock input                               32khz  */
  input         ph1;           /* clock phase 1                                       bus  */
  input         ph2;           /* clock phase 2                                       bus  */
  input         pwr_up;        /* power on reset                                      por  */
  input         pwo;           /* power on                                            bus  */
  input         spi_csn;       /* spi chip select: pullup                             ffc  */
  input         spi_sck;       /* spi serial clock: pulldown                          ffc  */
  input         spi_si;        /* spi serial input: pullup                            ffc  */
  input         sync;          /* synchronization                                     bus  */

  output        data_drv;      /* memory/peripheral data bus                          bus  */
  output        data_out;      /* memory/peripheral data bus                          bus  */
  output        fi_drv;        /* flag bus                                            bus  */
  output        fi_out;        /* flag bus                                            bus  */
  output        isa_drv;       /* instruction address/data bus                        bus  */
  output        isa_out;       /* instruction address/data bus                        bus  */
  output        spi_so;        /* spi serial output                                   ffc  */

  /*****************************************************************************************/
  /* signal declarations                                                                   */
  /*****************************************************************************************/
  wire        c100_pls;                                    /* 100Hz                        */
  wire        data_drv;                                    /* memory/peripheral data bus   */
  wire        data_out;                                    /* memory/peripheral data bus   */
  wire        fi_drv;                                      /* flag bus                     */
  wire        fi_out;                                      /* flag bus                     */
  wire        isa_drv_c;                                   /* drive isa_bus (core)         */
  wire        isa_drv_r;                                   /* drive isa_bus (rom)          */
  wire        isa_out_r;                                   /* data: isa_bus (rom)          */

  wire        ph1_buf;                                     /* buffered clock phase 1       */
  wire        ph2_buf;                                     /* buffered clock phase 2       */
  wire        pwob;                                        /* power on (inverted)          */
  wire        pwr_upb;                                     /* power on reset (inverted)    */

  wire        spi_so;                                      /* spi serial output            */

  /*****************************************************************************************/
  /* global buffers                                                                        */
  /*****************************************************************************************/
`ifdef SIM_VERSION

  assign      ph1_buf = ph1;
  assign      ph2_buf = ph2;
  assign      pwob    = !pwo;
  assign      pwr_upb = !pwr_up;

`else

  SB_GB  PH1     ( .USER_SIGNAL_TO_GLOBAL_BUFFER(ph1),
                   .GLOBAL_BUFFER_OUTPUT(ph1_buf) );

  SB_GB  PH2     ( .USER_SIGNAL_TO_GLOBAL_BUFFER(ph2),
                   .GLOBAL_BUFFER_OUTPUT(ph2_buf) );

  SB_GB  PWO     ( .USER_SIGNAL_TO_GLOBAL_BUFFER(!pwo),
                   .GLOBAL_BUFFER_OUTPUT(pwob) );

  SB_GB  PWR_UP  ( .USER_SIGNAL_TO_GLOBAL_BUFFER(!pwr_up),
                   .GLOBAL_BUFFER_OUTPUT(pwr_upb) );

`endif

  /*****************************************************************************************/
  /* bus drivers                                                                           */
  /*****************************************************************************************/
  assign isa_drv  = isa_drv_c || isa_drv_r;
  assign isa_out  = isa_drv_c || isa_out_r;

  /*****************************************************************************************/
  /* time core                                                                             */
  /*****************************************************************************************/
  tim_core CORE ( .c100_pls(c100_pls), .data_drv(data_drv), .data_out(data_out),
                  .isa_drv(isa_drv_c), .fi_drv(fi_drv), .fi_out(fi_out),
                  .data_bus(data_bus), .isa_bus(isa_bus), .osc_in(osc_in),
                  .ph1(ph1_buf), .ph2(ph2_buf), .pwr_upb(pwr_upb), .pwob(pwob),
                  .sync(sync) );

  /*****************************************************************************************/
  /* page 5 instruction memory                                                             */
  /*****************************************************************************************/
`define TIMER

  imem_fpga ROM ( .isa_drv(isa_drv_r), .isa_out(isa_out_r), .data_bus(data_bus),
                  .enabl_rd(1'b1), .enabl_wr(1'b0), .isa_bus(isa_bus), .page_addr(4'b0101),
                  .ph1(ph1_buf), .ph2(ph2_buf), .pwob(pwob), .sync(sync) );

  /*****************************************************************************************/
  /* ffc signal placeholder                                                                */
  /*****************************************************************************************/
  assign spi_so = (spi_csn || spi_sck || spi_si) && c100_pls;

  endmodule





